# eric7.Preferences.ConfigurationPages.MicroPythonPage

Module implementing the MicroPython configuration page.

### Global Attributes

None

### Classes

MicroPythonPage | Class implementing the MicroPython configuration page.

### Functions

create | Module function to create the configuration page.

## MicroPythonPage

Class implementing the MicroPython configuration page.

### Derived from

ConfigurationPageBase, Ui_MicroPythonPage

### Class Attributes

None

### Class Methods

None

### Methods

MicroPythonPage | Constructor
on_apShowPasswordButton_clicked | Private slot to show or hide the WiFi Access Point password.
on_showPasswordButton_clicked | Private slot to show or hide the WiFi client password.
save | Public slot to save the MicroPython configuration.

### Static Methods

None

#### MicroPythonPage (Constructor)

MicroPythonPage(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### MicroPythonPage.on_apShowPasswordButton_clicked

on_apShowPasswordButton_clicked(checked)

Private slot to show or hide the WiFi Access Point password.

checked (bool)
  state of the button

#### MicroPythonPage.on_showPasswordButton_clicked

on_showPasswordButton_clicked(checked)

Private slot to show or hide the WiFi client password.

checked (bool)
  state of the button

#### MicroPythonPage.save

save()

Public slot to save the MicroPython configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up